@@ -112,7 +112,6 @@
 #' get_labels(efc$e42dep)
 #' get_labels(efc$e42dep, drop.unused = TRUE)
 #' get_labels(efc$e42dep, non.labelled = TRUE, drop.unused = TRUE)
-#'
 #' @export
 get_labels <- function(x, attr.only = FALSE, values = NULL,
                        non.labelled = FALSE, drop.na = TRUE, drop.unused = FALSE) {
@@ -149,7 +148,6 @@ get_labels.default <- function(x, attr.only = FALSE, values = NULL,
 
 # Retrieve value labels of a data frame or variable
 # See 'get_labels'
-#' @importFrom haven is_tagged_na na_tag
 get_labels_helper <- function(x, attr.only, include.values, include.non.labelled, drop.na, drop.unused) {
 
   labels <- attr(x, "labels", exact = TRUE)
@@ -171,8 +169,11 @@ get_labels_helper <- function(x, attr.only, include.values, include.non.labelled
       }
     }
   } else {
+
     # drop na?
-    if (drop.na) labels <- labels[!haven::is_tagged_na(labels)]
+    if (isTRUE(drop.na) && requireNamespace("haven", quietly = TRUE)) {
+      labels <- labels[!haven::is_tagged_na(labels)]
+    }
 
     # check if we have anything
     if (!is.null(labels) && length(labels) > 0) {
@@ -192,9 +193,11 @@ get_labels_helper <- function(x, attr.only, include.values, include.non.labelled
 
       # do we have any tagged NAs? If so, get tagged NAs
       # and annotate them properly
-      if (any(haven::is_tagged_na(values))) {
-        values[haven::is_tagged_na(values)] <-
-          paste0("NA(", haven::na_tag(values[haven::is_tagged_na(values)]), ")")
+      if (requireNamespace("haven", quietly = TRUE)) {
+        if (any(haven::is_tagged_na(values))) {
+          values[haven::is_tagged_na(values)] <-
+            paste0("NA(", haven::na_tag(values[haven::is_tagged_na(values)]), ")")
+        }
       }
 
       # do we want to include non-labelled values as well? if yes,
